<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Dialog</name>
    <message>
        <location filename="../TextDialog/CharacterMapDialog.ui" line="+14"/>
        <source>Character Map</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Tablica znaków</translation>
    </message>
</context>
<context>
    <name>Text</name>
    <message>
        <location filename="../Text.js" line="+88"/>
        <source>Position</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wskaż położenie linii wymiarowej lub wprowadź kąt:
Wskaż położenie linii wymiarowej lub wprowadź kąt
Wskaż pozycje</translatorcomment>
        <translation>Położenie</translation>
    </message>
    <message>
        <location filename="../Text.ui" line="+17"/>
        <source>Contents:</source>
        <translatorcomment>--ignored colon--
--file: assistant_pl.ts--
Błąd podczas wklejania zawartości schowka: Brak głównego elementu &lt;ui&gt;.
Błąd podczas wklejania zawartości schowka: Brak głównego elementu &lt;ui&gt;</translatorcomment>
        <translation>Zawartość:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Height:</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wysokość:
Wysokość tekstu:</translatorcomment>
        <translation>Wysokość:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Angle:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź kąt:
Wskaż położenie linii wymiarowej:</translatorcomment>
        <translation>Kąt:</translation>
    </message>
    <message>
        <location filename="../TextInit.js" line="+2"/>
        <source>&amp;Text</source>
        <translatorcomment>--exact match--
--file: designer_pl.ts--
&amp;Tekst
&amp;Tekst:</translatorcomment>
        <translation>&amp;Tekst</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw text</source>
        <translatorcomment>--google--
Rysuj obiekty tekstowe</translatorcomment>
        <translation>Rysuje tekst</translation>
    </message>
</context>
<context>
    <name>TextDialog</name>
    <message>
        <location filename="../TextDialog/TextDialog.js" line="+242"/>
        <source>Default value:</source>
        <translation>Domyślna wartość:</translation>
    </message>
    <message>
        <location line="+266"/>
        <source>&amp;Undo</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
&amp;Cofnij</translatorcomment>
        <translation>&amp;Cofnij</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Redo</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
&amp;Przywróć</translatorcomment>
        <translation>&amp;Ponów</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Cu&amp;t</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
W&amp;ytnij
Wy&amp;tnij z punktem odniesienia</translatorcomment>
        <translation>Wy&amp;tnij</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Copy</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
S&amp;kopiuj
Kopiuj z punktem &amp;odniesienia</translatorcomment>
        <translation>S&amp;kopiuj</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Paste</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
&amp;Wklej</translatorcomment>
        <translation>Wkl&amp;ej</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Bold</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>&amp;Pogrubienie</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Italic</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>&amp;Kursywa</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Subscript</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Indeks &amp;dolny</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Superscript</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Indeks gó&amp;rny</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>&amp;Color...</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>&amp;Kolor...</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Special Characters...</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Znaki &amp;specjalne...</translation>
    </message>
    <message>
        <location line="+305"/>
        <source>Others...</source>
        <translatorcomment>--ignored ...--
--file: qcadguiqt_pl.ts--</translatorcomment>
        <translation>Inne...</translation>
    </message>
    <message>
        <location line="+131"/>
        <source>Degree</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
° (Stopień)
Stopnie dziesiętne</translatorcomment>
        <translation>Stopień</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plus-Minus</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Plus-minus</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Diameter</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Przełącz znak średnicy
ø (Średnica)</translatorcomment>
        <translation>Średnica</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Almost equal</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Prawie równe</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Multiplication</source>
        <translatorcomment>--google--
Mnożenie wartości typu %1 przez %2 lub %3 (plus lub minus nieskończoność) jest niedozwolone.
Mnożenie wartości typu %1 przez %2 lub %3 (plus lub minus nieskończoność) jest niedozwolone</translatorcomment>
        <translation>Mnożenie</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Division</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
÷ (Dzielenie)
Dzielenie (÷)</translatorcomment>
        <translation>Dzielenie</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Delta</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Delta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pi</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Kopiuj obiekty do schowka
Kopiuje obiekty do schowka z punktem odniesienia</translatorcomment>
        <translation>Pi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Identity</source>
        <translatorcomment>--google--
Selektor narzucenia niepowtarzalności W3C XML Schema
Pole narzucenia niepowtarzalności W3C XML Schema
%1 odwołuje się do narzucenia niepowtarzalności %2 które nie jest elementem %3 ani %4.</translatorcomment>
        <translation>Tożsamość</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Not equal</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Nie równe</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Ohm</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Om</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Omega</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Omega</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Squared</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Do kwadratu</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Cubed</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Do sześcianu</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>No-break space</source>
        <translation>Spacja nierozdzielająca</translation>
    </message>
    <message>
        <location filename="../TextDialog/TextDialog.ui" line="+14"/>
        <source>Text</source>
        <translatorcomment>--exact match--
--file: qtconfig_pl.ts--
Wprowadź tekst wymiaru:
Wprowadź tekst wymiaru
Wprowadź tekst</translatorcomment>
        <translation>Tekst</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Main Font</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Główna czcionka</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Height:</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wysokość:
Wysokość tekstu:</translatorcomment>
        <translation>Wysokość:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Text Height in Drawing Units</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Określa wysokość tekstu w jednostkach rysunku</translation>
    </message>
    <message>
        <location line="+18"/>
        <location line="+268"/>
        <source>Bold</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Pogrubiony
Na wpół pogrubiony</translatorcomment>
        <translation>Pogrubienie</translation>
    </message>
    <message>
        <location line="-261"/>
        <location line="+274"/>
        <source>Italic</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
[10300-1032F] Old Italic
Old Italic</translatorcomment>
        <translation>Kursywa</translation>
    </message>
    <message>
        <location line="-260"/>
        <source>Text fits on one line and has no formatting</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Wpisuje tekst w jednym wierszu, bez formatowania</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Simple text
(one line, no formatting)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Prosty tekst (jeden wiersz, nie formatowany)</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Rich Text</source>
        <translatorcomment>--exact match--
--file: designer_pl.ts--
Zmień tekst sformatowany...
Zmień tekst sformatowany
Rich Text</translatorcomment>
        <translation>Tekst sformatowany</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Cut</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wytnij
Wytnij obiekty do schowka</translatorcomment>
        <translation>Wytnij</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Copy</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Skopiuj
S&amp;kopiuj</translatorcomment>
        <translation>Skopiuj</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Paste</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wklej
&amp;Wklej</translatorcomment>
        <translation>Wklej</translation>
    </message>
    <message>
        <location line="+170"/>
        <source>Ctrl+B</source>
        <translatorcomment>--exact match--
--file: linguist_pl.ts--
CTRL+B
Ctrl+B</translatorcomment>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Ctrl+I</source>
        <translatorcomment>--ignored case--
--file: designer_pl.ts--
CTRL+I</translatorcomment>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Insert Symbol...</source>
        <translatorcomment>--ignored ...--
--file: qcadguiqt_pl.ts--</translatorcomment>
        <translation>Wstaw symbol...</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Source</source>
        <translatorcomment>--exact match--
--file: linguist_pl.ts--
Ścieżki do plików źródłowych dokumentacji:
Ścieżki do plików źródłowych dokumentacji
Ścieżki do plików źródłowych</translatorcomment>
        <translation>Źródło</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Attribute Details</source>
        <translation>Szczegóły atrybutu</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Tag:</source>
        <translation>Znacznik:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Prompt:</source>
        <translation>Etykieta:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Value:</source>
        <translation>Wartość:</translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Text Geometry</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Geometria tekstu</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Line spacing factor:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Współczynnik odstępu wierszy:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Line Spacing Factor</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
Współczynnik odstępu między liniami</translatorcomment>
        <translation>Określa sspółczynnik odległości między wierszami</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Angle:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź kąt:
Wskaż położenie linii wymiarowej:</translatorcomment>
        <translation>Kąt:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Rotation Angle</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź kąt obrotu:
Wprowadź kąt obrotu
Kąt obracania</translatorcomment>
        <translation>Określa kąt obrotu</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Alignment</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wyrównanie
Wyrównanie|Pionowe</translatorcomment>
        <translation>Wyrównanie</translation>
    </message>
    <message>
        <location line="+79"/>
        <source>Top Center</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Góra - środek</translatorcomment>
        <translation>Góra - środek</translation>
    </message>
    <message>
        <location line="+145"/>
        <source>Base Left</source>
        <translation>Podstawa - lewo</translation>
    </message>
    <message>
        <location line="-177"/>
        <source>Top Left</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Góra - lewo</translatorcomment>
        <translation>Góra - lewo</translation>
    </message>
    <message>
        <location line="+206"/>
        <source>Base Center</source>
        <translation>Podstawa - środek</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Base Right</source>
        <translation>Podstawa - prawo</translation>
    </message>
    <message>
        <location line="-145"/>
        <source>Top Right</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Góra - prawo</translatorcomment>
        <translation>Góra - prawo</translation>
    </message>
    <message>
        <location line="+203"/>
        <source>Bottom Center</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Dół - środek</translatorcomment>
        <translation>Dół - środek</translation>
    </message>
    <message>
        <location line="-145"/>
        <source>Middle Left</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Środek - lewo</translatorcomment>
        <translation>Środek - lewo</translation>
    </message>
    <message>
        <location line="-29"/>
        <source>Middle Center</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Środek - środek</translatorcomment>
        <translation>Środek - środek</translation>
    </message>
    <message>
        <location line="-58"/>
        <source>Middle Right</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Środek - prawo</translatorcomment>
        <translation>Środek - prawo</translation>
    </message>
    <message>
        <location line="+203"/>
        <source>Bottom Left</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Dół - lewo</translatorcomment>
        <translation>Dół - lewo</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Bottom Right</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Dół - prawo</translatorcomment>
        <translation>Dół - prawo</translation>
    </message>
    <message>
        <location line="+59"/>
        <source>Cancel</source>
        <translatorcomment>--exact match--
--file: qvfb_pl.ts--
Anuluj
&amp;Anuluj</translatorcomment>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>OK</source>
        <translatorcomment>--exact match--
--file: qvfb_pl.ts--
OK
&amp;OK</translatorcomment>
        <translation>OK</translation>
    </message>
</context>
</TS>
